//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by C:\work\pismere\athena\auth\krb5\src\windows\identity\ui\lang\en_us\khapp.rc
//
#define IDI_MAIN_APP                    104
#define IDD_PP_CRED                     106
#define IDD_PP_IDENT                    107
#define IDB_TK_REFRESH                  108
#define IDS_MAIN_WINDOW_TITLE           108
#define IDS_MENU_FILE                   109
#define IDB_ID                          110
#define IDS_MENU_CRED                   110
#define IDB_ID_DELETE                   111
#define IDS_MENU_VIEW                   111
#define IDB_ID_NEW                      112
#define IDS_MENU_OPTIONS                112
#define IDB_ID_REFRESH                  113
#define IDS_MENU_HELP                   113
#define IDB_TK                          114
#define IDS_ACTION_PROPERTIES           114
#define IDB_TK_DELETE                   115
#define IDS_ACTION_EXIT                 115
#define IDB_TK_NEW                      116
#define IDS_CFG_ROOT_NAME               116
#define IDS_ACTION_SET_DEF_ID           117
#define IDS_ACTION_SET_SRCH_ID          118
#define IDB_VW_REFRESH_SM               118
#define IDR_MENU_BAR                    119
#define IDS_CFG_ROOT_TITLE              119
#define IDS_CFG_GENERAL_SHORT           120
#define IDB_TB_BLANK                    121
#define IDS_ACTION_NEW_CRED             121
#define IDS_ACTION_PASSWD_ID            122
#define IDS_ACTION_CHOOSE_COLS          123
#define IDB_TB_BLANK_SM                 123
#define IDS_ACTION_DEBUG_WINDOW         124
#define IDB_VW_REFRESH                  124
#define IDS_ACTION_VIEW_REFRESH         125
#define IDB_ID_DELETE_DIS               125
#define IDS_MENU_LAYOUT                 126
#define IDB_ID_DELETE_DIS_SM            126
#define IDS_MENU_TOOLBARS               127
#define IDB_ID_DELETE_SM                127
#define IDS_ACTION_LAYOUT_ID            128
#define IDB_ID_DIS                      128
#define IDS_ACTION_LAYOUT_TYPE          129
#define IDB_ID_DIS_SM                   129
#define IDS_ACTION_LAYOUT_LOC           130
#define IDB_ID_NEW_DIS                  130
#define IDS_ACTION_TB_STANDARD          131
#define IDB_ID_NEW_DIS_SM               131
#define IDS_ACTION_OPT_KHIM             132
#define IDB_ID_NEW_SM                   132
#define IDB_ID_REFRESH_DIS              133
#define IDS_ACTION_OPT_IDENTS           133
#define IDS_ACTION_OPT_NOTIF            134
#define IDB_ID_REFRESH_SM               134
#define IDS_ACTION_HELP_CTX             135
#define IDB_ID_REFRESH_DIS_SM           135
#define IDS_ACTION_HELP_CONTENTS        136
#define IDB_TK_DELETE_DIS               136
#define IDS_ACTION_HELP_INDEX           137
#define IDB_TK_DELETE_DIS_SM            137
#define IDS_ACTION_HELP_ABOUT           138
#define IDB_TK_DELETE_SM                138
#define IDB_TK_DIS_SM                   139
#define IDS_CFG_GENERAL_LONG            139
#define IDB_TK_NEW_DIS                  140
#define IDS_SAMPLE_STRING               140
#define IDB_TK_NEW_DIS_SM               141
#define IDS_NO_CREDS                    141
#define IDB_TK_NEW_SM                   142
#define IDS_WT_INIT_CREDS               142
#define IDB_TK_REFRESH_DIS              143
#define IDS_WT_NEW_CREDS                143
#define IDB_TK_REFRESH_DIS_SM           144
#define IDS_NC_IDENTITY                 144
#define IDB_TK_REFRESH_SM               145
#define IDS_NC_IDENTS                   145
#define IDB_TK_SM                       146
#define IDS_NC_CREDTEXT_ID_NONE         146
#define IDB_HELP_SM                     147
#define IDS_NC_CREDTEXT_ID_ONE          147
#define IDB_HELP                        148
#define IDS_NC_CREDTEXT_ID_MANY         148
#define IDB_LOGO_SHADE                  149
#define IDS_NC_CREDTEXT_ID_INVALID      149
#define IDS_WTPOST_INIT_CREDS           150
#define IDS_WTPOST_NEW_CREDS            151
#define IDB_WDG_EXPAND                  152
#define IDS_ACTION_RENEW_CRED           152
#define IDB_WDG_COLLAPSE                153
#define IDS_ACTION_DESTROY_CRED         153
#define IDB_ID_SM                       154
#define IDS_DEFAULT_FONT                154
#define IDB_WDG_EXPAND_HI               155
#define IDS_NC_CREDTEXT_TABS            155
#define IDB_WDG_COLLAPSE_HI             156
#define IDS_NOTIFY_PREFIX               156
#define IDB_WDG_CREDTYPE                157
#define IDS_NOTIFY_READY                157
#define IDB_WDG_FLAG                    158
#define IDS_NOTIFY_ATTENTION            158
#define IDB_FLAG_WARN                   159
#define IDS_ALERT_DEFAULT               159
#define IDB_FLAG_EXPIRED                160
#define IDS_PACTION_OK                  160
#define IDB_FLAG_CRITICAL               161
#define IDS_PACTION_CANCEL              161
#define IDS_PACTION_CLOSE               162
#define IDD_NC_NEWCRED                  162
#define IDD_NC_BBAR                     163
#define IDS_ALERT_NOSEL_TITLE           163
#define IDS_ALERT_NOSEL                 164
#define IDI_ENABLED                     165
#define IDS_NC_CREDTEXT_ID_VALID        165
#define IDI_DISABLED                    166
#define IDS_NC_CREDTEXT_ID_UNCHECKED    166
#define IDS_PROP_COL_PROPERTY           167
#define IDS_PROP_COL_VALUE              168
#define IDI_NOTIFY_NONE                 169
#define IDS_NC_NEW_IDENT                169
#define IDI_NOTIFY_INFO                 170
#define IDS_NC_CREDTEXT_ID_CHECKING     170
#define IDI_NOTIFY_WARN                 171
#define IDS_ACTION_OPEN_APP             171
#define IDI_NOTIFY_ERROR                172
#define IDS_CTX_NEW_IDENT               172
#define IDS_CTX_NEW_CREDS               173
#define IDD_CFG_MAIN                    173
#define IDS_CTX_RENEW_CREDS             174
#define IDD_CFG_GENERIC                 174
#define IDS_CTX_PROC_NEW_IDENT          175
#define IDB_LOGO_OPAQUE                 175
#define IDS_CTX_PROC_NEW_CREDS          176
#define IDD_CFG_GENERAL                 176
#define IDS_CTX_PROC_RENEW_CREDS        177
#define IDD_CFG_IDENTITIES              177
#define IDS_ACTION_CLOSE_APP            178
#define IDD_CFG_NOTIF                   178
#define IDS_NC_FAILED_TITLE             179
#define IDD_CFG_PLUGINS                 179
#define IDS_CFG_IDENTITIES_SHORT        180
#define IDD_CFG_IDENTITY                180
#define IDS_CFG_IDENTITIES_LONG         181
#define IDI_CFG_DEFAULT                 181
#define IDS_CFG_NOTIF_SHORT             182
#define IDI_CFG_MODIFIED                182
#define IDS_CFG_NOTIF_LONG              183
#define IDI_CFG_APPLIED                 183
#define IDS_CFG_PLUGINS_SHORT           184
#define IDD_CFG_IDS_TAB                 184
#define IDS_CFG_PLUGINS_LONG            185
#define IDD_CFG_ID_TAB                  185
#define IDS_CFG_IDENTITY_SHORT          186
#define IDI_CFG_DELETED                 186
#define IDS_CFG_IDENTITY_LONG           187
#define IDI_ID                          187
#define IDS_CTX_DESTROY_CREDS           188
#define IDB_IMPORT_SM_DIS               188
#define IDS_WARN_EXPIRE                 189
#define IDB_IMPORT                      189
#define IDS_WARN_TITLE                  190
#define IDB_IMPORT_DIS                  190
#define IDS_ALERT_MOREINFO              191
#define IDB_IMPORT_SM                   191
#define IDS_WARN_EXPIRED                192
#define IDB_CHPW_SM                     192
#define IDS_WARN_EXPIRE_ID              193
#define IDB_CHPW                        193
#define IDS_WARN_EXPIRED_ID             194
#define IDB_CHPW_DIS                    194
#define IDS_WARN_WM_TITLE               195
#define IDB_CHPW_DIS_SM                 195
#define IDS_WARN_WM_MSG                 196
#define IDD_ABOUT                       196
#define IDS_CFG_ID_TAB_SHORT            197
#define IDB_TB_SPACE                    197
#define IDS_CFG_ID_TAB_LONG             198
#define IDB_WDG_STUCK_HI                198
#define IDS_CFG_IDS_TAB_SHORT           199
#define IDB_WDG_STICK                   199
#define IDS_CFG_IDS_TAB_LONG            200
#define IDB_WDG_STICK_HI                200
#define IDS_CFG_IDS_IDENTITY            201
#define IDB_WDG_STUCK                   201
#define IDS_ACTION_IMPORT               202
#define IDS_CTX_IMPORT                  203
#define IDB_FLAG_RENEW                  203
#define IDS_CFG_PI_COL_PLUGINS          204
#define IDI_APPICON_WARN                204
#define IDS_PISTATE_FAILUNK             205
#define IDI_APPICON_EXP                 205
#define IDS_PISTATE_FAILMAX             206
#define IDI_APPICON_OK                  206
#define IDS_PISTATE_FAILREG             207
#define IDI_CFG_PLUGIN                  207
#define IDS_PISTATE_FAILDIS             208
#define IDI_CFG_PLUGIN_ERR              208
#define IDS_PISTATE_FAILLOD             209
#define IDI_CFG_PLUGIN_DIS              209
#define IDS_PISTATE_PLACEHOLD           210
#define IDD_CFG_APPEAR                  210
#define IDS_PISTATE_REG                 211
#define IDD_CFG_ADDIDENT                211
#define IDS_PISTATE_HOLD                212
#define IDD_CMDLINE                     212
#define IDS_PISTATE_INIT                213
#define IDR_CMDLINERTF                  213
#define IDS_PISTATE_RUN                 214
#define IDS_PISTATE_EXIT                215
#define IDS_CTX_PASSWORD                216
#define IDS_WT_PASSWORD                 217
#define IDS_WTPOST_PASSWORD             218
#define IDS_CTX_PROC_PASSWORD           219
#define IDS_NC_PWD_FAILED_TITLE         220
#define IDS_MENU_SETDEF                 221
#define IDS_PACTION_NEXT                222
#define IDS_ERR_TITLE_NO_IDENTPRO       223
#define IDS_ERR_MSG_NO_IDENTPRO         224
#define IDS_ERR_SUGG_NO_IDENTPRO        225
#define IDS_NC_REN_FAILED_TITLE         226
#define IDS_CW_DEFAULT                  227
#define IDS_ACTION_OPT_PLUGINS          228
#define IDS_NC_SETDEF                   229
#define IDS_NC_ID_DEF                   230
#define IDS_NC_ID_WDEF                  231
#define IDS_NC_ID_NDEF                  232
#define IDS_PACTION_YES                 233
#define IDS_PACTION_NO                  234
#define IDS_PACTION_YESALL              235
#define IDS_PACTION_NOALL               236
#define IDS_PACTION_KEEP                237
#define IDS_PACTION_REMOVE              238
#define IDS_PACTION_DISCARD             239
#define IDS_CFG_IT_MOD                  240
#define IDS_CFG_IT_APP                  241
#define IDS_CFG_IT_NONE                 242
#define IDS_CFG_NODESC                  243
#define IDS_CFG_P_DELCNFT               244
#define IDS_CFG_P_DELCNFM               245
#define IDS_CFG_P_DELCNFS               246
#define IDS_CFG_P_DELNDEP               247
#define IDS_CFG_P_ENBCNFT               248
#define IDS_CFG_P_ENBCNFM               249
#define IDS_PISTATE_FAILINIT            250
#define IDS_CFG_P_UNRCNFT               251
#define IDS_CFG_P_UNRCNFM               252
#define IDS_CFG_P_UNRCNFS               253
#define IDS_ACTION_LAYOUT_CUST          254
#define IDS_APR_HEADER_TEXT             255
#define IDS_APR_HEADER_TEXT_BOLD        256
#define IDS_APR_TEXT                    257
#define IDS_APR_TEXT_BOLD               258
#define IDS_APR_SAMPLE_TEXT_NORMAL      259
#define IDS_CFG_APPEAR_SHORT            260
#define IDS_CFG_APPEAR_LONG             261
#define IDS_ACTION_OPT_APPEAR           262
#define IDS_APR_SAMPLE_TEXT_SEL         263
#define IDS_CFG_IDNAME_INV              264
#define IDS_CFG_IDNAME_PRB              265
#define IDS_CFG_IDNAME_EXT              266
#define IDS_CFG_IDNAME_CCR              267
#define IDS_CFG_IDNAME_CCC              268
#define IDS_CFG_LOGF_CS                 269
#define IDS_CFG_LOGF_CSR                270
#define IDS_ACTIONT_PROPERTIES          271
#define IDS_ACTIONT_EXIT                272
#define IDS_ACTIONT_SET_DEF_ID          273
#define IDS_ACTIONT_PASSWD_ID           274
#define IDS_ACTIONT_NEW_CRED            275
#define IDS_ACTIONT_RENEW_CRED          276
#define IDS_ACTIONT_DESTROY_CRED        277
#define IDS_ACTIONT_VIEW_REFRESH        278
#define IDS_ACTIONT_OPT_IDENTS          279
#define IDS_ACTIONT_OPT_KHIM            280
#define IDS_ACTIONT_OPT_NOTIF           281
#define IDS_ACTIONT_OPT_PLUGINS         282
#define IDS_ACTIONT_OPT_APPEAR          283
#define IDS_ACTIONT_HELP_CTX            284
#define IDS_ACTIONT_IMPORT              285
#define IDS_NC_FAILED_TITLE_I           286
#define IDS_NC_PWD_FAILED_TITLE_I       287
#define IDS_NC_REN_FAILED_TITLE_I       288
#define IDS_CFG_IDNAME_NON              289
#define IDS_MENU_DESTROY_CRED           290
#define IDS_MENU_RENEW_CRED             291
#define IDS_ACTION_DESTROY_ALL          292
#define IDS_ACTION_RENEW_ALL            293
#define IDS_IDACTION_RENEW              294
#define IDS_IDACTION_DESTROY            295
#define IDS_CTX_DESTROY_ID              296
#define IDS_NCN_IDENT_INVALID           297
#define IDS_NCN_IDENT_CHECKING          298
#define IDS_NCN_IDENT_UNKNOWN           299
#define IDS_REMOTE_FAIL                 300
#define IDS_REMOTE_FAIL_TITLE           301
#define IDS_IDACTION_NEW                302
#define IDS_IDACTIONT_NEW               303
#define IDS_IDACTIONT_RENEW             304
#define IDS_IDACTIONT_DESTROY           305
#define IDS_ALERTTYPE_PLUGIN            306
#define IDS_ALERTTYPE_EXPIRE            307
#define IDS_ALERTTYPE_RENEWFAIL         308
#define IDS_ALERTTYPE_ACQUIREFAIL       309
#define IDS_ALERTTYPE_CHPW              310
#define IDS_ACTION_LAYOUT_MINI          311
#define IDS_IDEXPDISP_NOCRED            312
#define IDS_IDEXPDISP_1CRED             313
#define IDS_IDEXPDISP_NCRED             314
#define IDS_CW_DEFAULTTF                315
#define IDS_CW_TYPEF                    316
#define IDS_CW_EXPIREF                  317
#define IDS_CW_EXPIRED                  318
#define IDS_IDACTIONT_SETDEF            319
#define IDS_IDACTION_SETDEF             320
#define IDS_ACTION_VIEW_ALL_IDS         321
#define IDC_NC_CREDTEXT_LABEL           1009
#define IDC_NC_CREDTEXT                 1012
#define IDC_NC_HELP                     1017
#define IDC_NC_ADVANCED                 1019
#define IDC_PP_IDNAME                   1026
#define IDC_PP_IDDEF                    1027
#define IDC_PP_IDSEARCH                 1028
#define IDC_PP_PROPLIST                 1035
#define IDC_PP_CPROPLIST                1036
#define IDC_NC_TPL_ROW                  1039
#define IDC_NC_TPL_PANEL                1040
#define IDC_NC_TPL_LABEL                1041
#define IDC_NC_TPL_INPUT                1042
#define IDC_NC_TPL_LABEL_LG             1043
#define IDC_NC_TPL_INPUT_LG             1044
#define IDC_NC_TPL_ROW_LG               1045
#define IDC_CFG_NODELIST                1045
#define IDAPPLY                         1048
#define IDC_CFG_TITLE                   1050
#define IDC_CFG_PANE                    1051
#define IDC_NOTIF_MONITOR               1053
#define IDC_PP_DUMMY                    1054
#define IDC_NOTIF_RENEW                 1055
#define IDC_NOTIF_RENEW_THR             1056
#define IDC_NOTIF_WARN1                 1057
#define IDC_NOTIF_WARN1_THR             1058
#define IDC_NOTIF_WARN2                 1059
#define IDC_NOTIF_WARN2_THR             1060
#define IDC_CFG_KEEPRUNNING             1061
#define IDC_CFG_STARTUP_GROUP           1062
#define IDC_CFG_AUTOSTART               1063
#define IDC_CFG_AUTOIMPORT              1064
#define IDC_CFG_AUTOINIT                1065
#define IDC_CFG_OTHER                   1066
#define IDC_CFG_MONITOR                 1069
#define IDC_CFG_STICKY                  1070
#define IDC_CFG_RENEW                   1075
#define IDC_CFG_REMOVE                  1076
#define IDC_CFG_TAB                     1077
#define IDC_CFG_TARGET                  1078
#define IDC_CFG_PLUGINS                 1079
#define IDC_CFG_DESC                    1084
#define IDC_CFG_LBL_STATE               1085
#define IDC_CFG_STATE                   1086
#define IDC_CFG_LBL_DEPS                1087
#define IDC_CFG_DEPS                    1088
#define IDC_CFG_DISABLE                 1089
#define IDC_CFG_ENABLE                  1090
#define IDC_CFG_LBL_MOD                 1092
#define IDC_CFG_MODULE                  1093
#define IDC_CFG_LBL_VEN                 1094
#define IDC_CFG_VENDOR                  1095
#define IDC_CFG_REGISTER                1097
#define IDC_CFG_NETDETECT               1098
#define IDC_PP_STICKY                   1099
#define IDC_PRODUCT                     1100
#define IDC_COPYRIGHT                   1101
#define IDC_BUILDINFO                   1102
#define IDC_MODULES                     1103
#define IDC_PP_CONFIG                   1104
#define IDC_CFG_UNREGISTER              1107
#define IDC_CFG_VERSION                 1108
#define IDC_CFG_ICON                    1109
#define IDC_CFG_LOGTOFILE               1110
#define IDC_CFG_LOGPATH                 1111
#define IDC_NOTIF_HALFLIFE              1112
#define IDC_CFG_DESTROYALL              1113
#define IDC_CFG_SAMPLE_NORMAL           1123
#define IDC_CFG_REVERT                  1127
#define IDC_CFG_FONTS                   1128
#define IDC_CFG_SAMPLE_BOLD             1129
#define IDC_CFG_SIZE                    1130
#define IDC_CFG_BOLD                    1131
#define IDC_CFG_ITALICS                 1132
#define IDC_CFG_ADDIDENT                1133
#define IDC_SM_CTL                      1134
#define IDC_CFG_SHOWLOG                 1135
#define IDC_MED_CTL                     1135
#define IDC_LG_CTL                      1136
#define IDC_SM_LBL                      1137
#define IDC_MED_LBL                     1138
#define IDC_LG_LBL                      1139
#define IDC_CFG_NOTACTION               1141
#define IDC_CFG_NOTACT_STATIC           1142
#define IDC_NC_BASIC                    1143
#define IDC_CONTENT                     1144
#define IDA_ACTIVATE_MENU               40003
#define IDA_UP                          40004
#define IDA_DOWN                        40005
#define IDA_LEFT                        40006
#define IDA_RIGHT                       40007
#define IDA_ESC                         40008
#define IDA_ENTER                       40009

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        214
#define _APS_NEXT_COMMAND_VALUE         40010
#define _APS_NEXT_CONTROL_VALUE         1145
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
